==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebStepperDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescriptionMetadata } from "./WebStepDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescriptionMetadata } from "./WebActiveStepChangingArgsEventArgsDescriptionMetadata";
import { WebActiveStepChangedArgsEventArgsDescriptionMetadata } from "./WebActiveStepChangedArgsEventArgsDescriptionMetadata";
import { WebStepperDescription } from "./WebStepperDescription";
/**
 * @hidden
 */
export let WebStepperDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepperDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepperDescriptionMetadata.a == null) {
                WebStepperDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepperDescriptionMetadata.c(WebStepperDescriptionMetadata.a);
            }
            if (a.k(WebStepperDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebStepperDescriptionMetadata.a);
            WebStepDescriptionMetadata.d(a);
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.d(a);
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Stepper");
            a.item("__tagNameWC", "String:igc-stepper");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Steps", "Array:WebStepDescription:Step");
            a.item("Orientation", "ExportedType:string:StepperOrientation");
            a.item("Orientation@stringUnion", "WebComponents;React");
            a.item("Orientation@names", "Vertical;Horizontal");
            a.item("StepType", "ExportedType:string:StepperStepType");
            a.item("StepType@stringUnion", "WebComponents;React");
            a.item("StepType@names", "Indicator;Title;Full");
            a.item("Linear", "Boolean");
            a.item("ContentTop", "Boolean");
            a.item("Dir", "ExportedType:string:Direction");
            a.item("Dir@stringUnion", "WebComponents;React");
            a.item("Dir@names", "Ltr;Rtl;Auto");
            a.item("TitlePosition", "ExportedType:string:StepperTitlePosition");
            a.item("TitlePosition@stringUnion", "WebComponents;React");
            a.item("TitlePosition@names", "Top;Bottom;Start;End");
            a.item("Size", "ExportedType:string:SizableComponentSize");
            a.item("Size@names", "Large;Small;Medium");
            a.item("ActiveStepChangingRef", "EventRef::activeStepChanging");
            a.item("ActiveStepChangedRef", "EventRef::activeStepChanged");
        }
        static d(a) {
            WebStepperDescriptionMetadata.b(a);
            a.ad("WebStepper", () => new WebStepperDescription());
            a.ac("WebStepper", WebStepperDescriptionMetadata.a);
        }
    }
    WebStepperDescriptionMetadata.$t = /*@__PURE__*/ markType(WebStepperDescriptionMetadata, 'WebStepperDescriptionMetadata');
    WebStepperDescriptionMetadata.a = null;
    return WebStepperDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebStepperDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebStepDescriptionMetadata } from "./WebStepDescriptionMetadata";
import { WebActiveStepChangingArgsEventArgsDescriptionMetadata } from "./WebActiveStepChangingArgsEventArgsDescriptionMetadata";
import { WebActiveStepChangedArgsEventArgsDescriptionMetadata } from "./WebActiveStepChangedArgsEventArgsDescriptionMetadata";
import { WebStepperDescription } from "./WebStepperDescription";
/**
 * @hidden
 */
export let WebStepperDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebStepperDescriptionMetadata extends Base {
        static b(a) {
            if (WebStepperDescriptionMetadata.a == null) {
                WebStepperDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebStepperDescriptionMetadata.c(WebStepperDescriptionMetadata.a);
            }
            if (a.k(WebStepperDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebStepperDescriptionMetadata.a);
            WebStepDescriptionMetadata.d(a);
            WebActiveStepChangingArgsEventArgsDescriptionMetadata.d(a);
            WebActiveStepChangedArgsEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:Stepper");
            a.item("__tagNameWC", "String:igc-stepper");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Steps", "Array:WebStepDescription:Step");
            a.item("Orientation", "ExportedType:string:StepperOrientation");
            a.item("Orientation@stringUnion", "WebComponents;React");
            a.item("Orientation@names", "Horizontal;Vertical");
            a.item("StepType", "ExportedType:string:StepperStepType");
            a.item("StepType@stringUnion", "WebComponents;React");
            a.item("StepType@names", "Indicator;Title;Full");
            a.item("Linear", "Boolean");
            a.item("ContentTop", "Boolean");
            a.item("VerticalAnimation", "ExportedType:string:StepperVerticalAnimation");
            a.item("VerticalAnimation@stringUnion", "WebComponents;React");
            a.item("VerticalAnimation@names", "None;Fade;Grow");
            a.item("HorizontalAnimation", "ExportedType:string:StepperHorizontalAnimation");
            a.item("HorizontalAnimation@stringUnion", "WebComponents;React");
            a.item("HorizontalAnimation@names", "None;Slide;Fade");
            a.item("AnimationDuration", "Number:double");
            a.item("TitlePosition", "ExportedType:string:StepperTitlePosition");
            a.item("TitlePosition@stringUnion", "WebComponents;React");
            a.item("TitlePosition@names", "Start;End;Bottom;Top");
            a.item("ActiveStepChangingRef", "EventRef::activeStepChanging");
            a.item("ActiveStepChangedRef", "EventRef::activeStepChanged");
        }
        static d(a) {
            WebStepperDescriptionMetadata.b(a);
            a.ae("WebStepper", () => new WebStepperDescription());
            a.ad("WebStepper", WebStepperDescriptionMetadata.a);
        }
    }
    WebStepperDescriptionMetadata.$t = /*@__PURE__*/ markType(WebStepperDescriptionMetadata, 'WebStepperDescriptionMetadata');
    WebStepperDescriptionMetadata.a = null;
    return WebStepperDescriptionMetadata;
})();
